@@ -252,7 +252,9 @@ func New(conf Config) (*ApiClient, error) {
 	}
 
 	if client.Transport == nil {
-		client.Transport = &http.Transport{}
+		client.Transport = &http.Transport{
+			Proxy: http.ProxyFromEnvironment,
+		}
 	}
 	// set connection timeout
 	client.Timeout = defaultClientReadingTimeout
@@ -274,12 +276,20 @@ func newHttpClient() *http.Client {
 	return &http.Client{}
 }
 
+type ClientServerCertificateError struct {
+	err error
+}
+
+func (s *ClientServerCertificateError) Error() string {
+	return errors.Wrapf(s.err, "cannot initialize server trust").Error()
+}
+
 func newHttpsClient(conf Config) (*http.Client, error) {
 	client := newHttpClient()
 
 	trustedcerts, err := loadServerTrust(conf)
 	if err != nil {
-		return nil, errors.Wrapf(err, "cannot initialize server trust")
+		return nil, &ClientServerCertificateError{err}
 	}
 
 	if conf.NoVerify {
@@ -291,6 +301,7 @@ func newHttpsClient(conf Config) (*http.Client, error) {
 	}
 	transport := http.Transport{
 		TLSClientConfig: &tlsc,
+		Proxy:           http.ProxyFromEnvironment,
 	}
 
 	client.Transport = &transport
