@@ -175,7 +175,7 @@ func processUpdateResponse(response *http.Response) (interface{}, error) {
 		return nil, ErrNotAuthorized
 
 	default:
-		log.Warn("Client recieved invalid response status code: ", response.StatusCode)
+		log.Warn("Client received invalid response status code: ", response.StatusCode)
 		return nil, errors.New("Invalid response received from server")
 	}
 }
