@@ -290,7 +290,7 @@ func (m *mender) CheckUpdate() (*datastore.UpdateInfo, menderError) {
 
 	deviceType, err := m.GetDeviceType()
 	if err != nil {
-		log.Errorf("Unable to verify the existing hardware. Update will continue anyways: %v : %v", defaultDeviceTypeFile, err)
+		log.Errorf("Unable to verify the existing hardware. Update will continue anyways: %v : %v", m.config.DeviceTypeFile, err)
 	}
 	haveUpdate, err := m.updater.GetScheduledUpdate(m.api.Request(m.authToken, nextServerIterator(m), reauthorize(m)),
 		m.config.Servers[0].ServerURL, client.CurrentUpdate{
@@ -544,7 +544,7 @@ func transitionState(to State, ctx *StateContext, c Controller) (State, bool) {
 				report.Report.Status = StateStatus(from.Id())
 			}
 			// call error scripts
-			from.Transition().Error(c.GetScriptExecutor(), report)
+			_ = from.Transition().Error(c.GetScriptExecutor(), report)
 		} else {
 			// do transition to ordinary state
 			if err := from.Transition().Leave(c.GetScriptExecutor(), report, ctx.store); err != nil {
@@ -605,7 +605,7 @@ func (m *mender) InventoryRefresh() error {
 
 	deviceType, err := m.GetDeviceType()
 	if err != nil {
-		log.Errorf("Unable to verify the existing hardware. Update will continue anyways: %v : %v", defaultDeviceTypeFile, err)
+		log.Errorf("Unable to verify the existing hardware. Update will continue anyways: %v : %v", m.config.DeviceTypeFile, err)
 	}
 	reqAttr := []client.InventoryAttribute{
 		{Name: "device_type", Value: deviceType},
@@ -616,7 +616,7 @@ func (m *mender) InventoryRefresh() error {
 	if idata == nil {
 		idata = make(client.InventoryData, 0, len(reqAttr))
 	}
-	idata.ReplaceAttributes(reqAttr)
+	_ = idata.ReplaceAttributes(reqAttr)
 
 	if idata == nil {
 		log.Infof("no inventory data to submit")
